UnsafeInstDecoder

Struct UnsafeInstDecoder 

pub struct UnsafeInstDecoder<'a> { /* private fields */ }
All of the unsafe methods of this type depend on the bytecode being previously validated and instructions being processed correctly. It should not be used outside of the bytecode interpreter.

Implementations

Source

impl<'a> UnsafeInstDecoder<'a>

pub fn new(bytecode: &'a [u8]) -> Self

pub unsafe fn opcode(&mut self) -> Opcode

Safety

Current offset must be in bounds and at valid opcode

pub unsafe fn uvar(&mut self) -> u64

Safety

Current offset must at valid unsigned integer within bounds

pub unsafe fn ivar(&mut self) -> i64

Safety

Current offset must at valid signed integer within bounds

pub unsafe fn usize(&mut self) -> usize

Safety

Current offset must at valid unsigned integer within bounds that fits in usize

pub unsafe fn isize(&mut self) -> isize

Safety

Current offset must at valid signed integer within bounds that fits in isize

pub unsafe fn seek(&mut self, offset: isize)

Safety

Target offset must be the start of an in-bounds instruction

pub fn offset(&self) -> usize